==> haskell-breakpoint-0.1.2.2-38-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-breakpoint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 breakpoint
version:              0.1.2.2
visibility:           public
id:                   breakpoint-0.1.2.2-KruOvtC8UOEDRBF9xXIDhj
key:                  breakpoint-0.1.2.2-KruOvtC8UOEDRBF9xXIDhj
license:              MIT
maintainer:           aaronallen8455@gmail.com
author:               Aaron Allen
synopsis:             Set breakpoints using a GHC plugin
description:
    A plugin that allows you to set breakpoints for debugging purposes.

    See the [README](https://github.com/aaronallen8455/breakpoint#breakpoint) for details.

category:             Development
abi:                  33ce67255cf69ad3d098df235df77b74
exposed:              True
exposed-modules:
    Debug.Breakpoint Debug.Breakpoint.GhcFacade
    Debug.Breakpoint.TimerManager

hidden-modules:       Debug.Breakpoint.Renamer Debug.Breakpoint.TypeChecker
import-dirs:          /usr/lib/ghc-9.2.8/site-local/breakpoint-0.1.2.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/breakpoint-0.1.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-breakpoint
hs-libraries:         HSbreakpoint-0.1.2.2-KruOvtC8UOEDRBF9xXIDhj
depends:
    ansi-terminal-0.11.4-Bavr5INHzaUHF3VuHy0Lqz base-4.16.4.0
    containers-0.6.5.1 deepseq-1.4.6.1 ghc-9.2.8 haskeline-0.8.2
    mtl-2.2.2 pretty-simple-4.1.2.0-ENlZRorZ6zSBGuiYeRYYHZ
    template-haskell-2.18.0.0 text-1.2.5.0 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-breakpoint/html/breakpoint.haddock
haddock-html:         /usr/share/doc/haskell-breakpoint/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-breakpoint-0.1.2.2-47-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-breakpoint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 breakpoint
version:              0.1.2.2
visibility:           public
id:                   breakpoint-0.1.2.2-LDlrSQawvy1KR7FZ7zHIZ3
key:                  breakpoint-0.1.2.2-LDlrSQawvy1KR7FZ7zHIZ3
license:              MIT
maintainer:           aaronallen8455@gmail.com
author:               Aaron Allen
synopsis:             Set breakpoints using a GHC plugin
description:
    A plugin that allows you to set breakpoints for debugging purposes.

    See the [README](https://github.com/aaronallen8455/breakpoint#breakpoint) for details.

category:             Development
abi:                  444c328b299c7ab8d637dd226555e978
exposed:              True
exposed-modules:
    Debug.Breakpoint Debug.Breakpoint.GhcFacade
    Debug.Breakpoint.TimerManager

hidden-modules:       Debug.Breakpoint.Renamer Debug.Breakpoint.TypeChecker
import-dirs:          /usr/lib/ghc-9.2.8/site-local/breakpoint-0.1.2.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/breakpoint-0.1.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-breakpoint
hs-libraries:         HSbreakpoint-0.1.2.2-LDlrSQawvy1KR7FZ7zHIZ3
depends:
    ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE base-4.16.4.0
    containers-0.6.5.1 deepseq-1.4.6.1 ghc-9.2.8 haskeline-0.8.2
    mtl-2.2.2 pretty-simple-4.1.2.0-4DdVydWy2oILgJsCq2PDX0
    template-haskell-2.18.0.0 text-1.2.5.0 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-breakpoint/html/breakpoint.haddock
haddock-html:         /usr/share/doc/haskell-breakpoint/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
